From c663b6440964f6ac48027143ac9e63298991f9d0 Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Sat, 31 Jul 2010 19:33:34 +0000
Subject: Trinity Qt initial conversion

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1157639 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 kcontrol/kthememanager/ktheme.h | 86 ++++++++++++++++++++---------------------
 1 file changed, 43 insertions(+), 43 deletions(-)

(limited to 'kcontrol/kthememanager/ktheme.h')

diff --git a/kcontrol/kthememanager/ktheme.h b/kcontrol/kthememanager/ktheme.h
index 1401b49e7..0ec3c94cf 100644
--- a/kcontrol/kthememanager/ktheme.h
+++ b/kcontrol/kthememanager/ktheme.h
@@ -19,11 +19,11 @@
 #ifndef KTHEME_H
 #define KTHEME_H
 
-#include <qdom.h>
-#include <qguardedptr.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qwidget.h>
+#include <tqdom.h>
+#include <tqguardedptr.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqwidget.h>
 
 #include <kurl.h>
 
@@ -47,14 +47,14 @@ public:
      * Constructs KTheme using an installed theme
      * @param xmlFile The theme's XML file
      */
-    KTheme( QWidget *parent, const QString & xmlFile );
+    KTheme( TQWidget *parent, const TQString & xmlFile );
 
     /**
      * Constructs an empty theme, to be used with
      * #createYourself()
      * @param create Whether to start the DOM tree
      */
-    KTheme( QWidget *parent, bool create = false );
+    KTheme( TQWidget *parent, bool create = false );
 
     /**
      * Destructor
@@ -74,7 +74,7 @@ public:
      * @param pack Whether to also pack the theme in tar.gz format
      * @return The path to the newly created tarball with theme (if @p pack == true)
      */
-    QString createYourself( bool pack = false );
+    TQString createYourself( bool pack = false );
 
     /**
      * Apply the theme to the system, ie. set the config variables and
@@ -87,41 +87,41 @@ public:
      * @param name The name of the theme
      * @return true on success
      */
-    static bool remove( const QString & name );
+    static bool remove( const TQString & name );
 
     /**
      * @return the theme name
      */
-    QString name() const { return m_name; }
+    TQString name() const { return m_name; }
     /**
      * Set the theme name
      */
-    void setName( const QString & name );
+    void setName( const TQString & name );
 
-    QString author() const {
+    TQString author() const {
         return getProperty( "author" );
     }
-    void setAuthor( const QString & author );
+    void setAuthor( const TQString & author );
 
-    QString email() const {
+    TQString email() const {
         return getProperty( "email" );
     }
-    void setEmail( const QString & email );
+    void setEmail( const TQString & email );
 
-    QString homepage() const {
+    TQString homepage() const {
         return getProperty( "homepage" );
     }
-    void setHomepage( const QString & homepage );
+    void setHomepage( const TQString & homepage );
 
-    QString comment() const {
+    TQString comment() const {
         return getProperty( "comment" );
     }
-    void setComment ( const QString & comment );
+    void setComment ( const TQString & comment );
 
-    QString version() const {
+    TQString version() const {
         return getProperty( "version" );
     }
-    void setVersion ( const QString & version );
+    void setVersion ( const TQString & version );
 
     /**
      * Creates a preview file called theme_name.preview.png
@@ -134,13 +134,13 @@ private:
      * Create a property with @p name, value @p value
      * and append it to @p parent element
      */
-    void setProperty( const QString & name,
-                      const QString & value,
-                      QDomElement parent );
+    void setProperty( const TQString & name,
+                      const TQString & value,
+                      TQDomElement parent );
     /**
      * Get a simple property from the "general" section of the DOM tree
      */
-    QString getProperty( const QString & name ) const;
+    TQString getProperty( const TQString & name ) const;
 
     /**
      * Get a property from the DOM tree, based on:
@@ -148,8 +148,8 @@ private:
      * @param tag From the this tag
      * @param attr From this attribute
      */
-    QString getProperty( QDomElement parent, const QString & tag,
-                         const QString & attr ) const;
+    TQString getProperty( TQDomElement parent, const TQString & tag,
+                         const TQString & attr ) const;
 
     /**
      * Creates a list of "icon" elements based on:
@@ -158,16 +158,16 @@ private:
      * @param parent Parent element to append to
      * @param cfg The KConfig object to work with
      */
-    void createIconElems( const QString & group, const QString & object,
-                          QDomElement parent, KConfig * cfg );
+    void createIconElems( const TQString & group, const TQString & object,
+                          TQDomElement parent, KConfig * cfg );
 
     /**
      * Creates a color DOM element @p name, with a specifier @p object,
      * appends it to @p parent; used when creating themes
      * @param cfg The KConfig object to work with
      */
-    void createColorElem( const QString & name, const QString & object,
-                          QDomElement parent, KConfig * cfg );
+    void createColorElem( const TQString & name, const TQString & object,
+                          TQDomElement parent, KConfig * cfg );
     /**
      * Creates a list of "event" elements based on:
      * @param events The list of events to work on
@@ -175,50 +175,50 @@ private:
      * @param parent Parent element to append to
      * @param cfg The KConfig object to work with
      */
-    void createSoundList( const QStringList & events, const QString & object,
-                          QDomElement parent, KConfig * cfg );
+    void createSoundList( const TQStringList & events, const TQString & object,
+                          TQDomElement parent, KConfig * cfg );
 
     /**
      * Tries to find out absolute path to a resource and copy it to the theme's temp dir;
      * used when creating themes
      * @param section The theme section to work on, corresponds to toplevel XML tags
      * @param path The original path, relative or absolute
      * @return an internal path suitable for writing into the XML file or QString::null
      * in case the resource couldn't be found
      */
-    QString processFilePath( const QString & section, const QString & path );
+    TQString processFilePath( const TQString & section, const TQString & path );
 
     /**
      * Converts an internal theme:/ representation of a resource
      * to a real path
      */
-    QString unprocessFilePath( const QString & section, QString path );
+    TQString unprocessFilePath( const TQString & section, TQString path );
 
     /**
      * Wrapper around KIO::NetAccess::file_copy
      */
-    bool copyFile( const QString & from, const QString & to );
+    bool copyFile( const TQString & from, const TQString & to );
 
     /**
      * Wrapper around KGlobal::dirs()->findResource()
      * @param section Section to work on (desktop, sounds, panel etc)
      * @param path The file to find
      */
-    QString findResource( const QString & section, const QString & path );
+    TQString findResource( const TQString & section, const TQString & path );
 
     /// name of the theme
-    QString m_name;
+    TQString m_name;
 
     /// DOM holding the theme
-    QDomDocument m_dom;
+    TQDomDocument m_dom;
     /// the DOM root element
-    QDomElement m_root;
+    TQDomElement m_root;
     /// "general" section
-    QDomElement m_general;
+    TQDomElement m_general;
 
     KStandardDirs * m_kgd;
 
-    QGuardedPtr<QWidget> m_parent;
+    TQGuardedPtr<TQWidget> m_parent;
 };
 
 #endif
@@ -175,50 +175,50 @@ private:
      * @param section The theme section to work on, corresponds to toplevel XML tags
      * @param path The original path, relative or absolute
-     * @return an internal path suitable for writing into the XML file or QString::null
+     * @return an internal path suitable for writing into the XML file or TQString::null
      * in case the resource couldn't be found
      */
-- 
cgit v1.2.1